@@ -31,7 +31,4 @@ test_that("Drop colr", {
   DT <- data.table(x = 1, y = 2, z = 3)
   DT_out <- drop_cols(DT, "x")
   expect_equal(names(DT_out), c("y", "z"))
-  
-  DF <- data.frame(x = 1, y = 1)
-  expect_error()
 })
